WebGamepad class
Web implementation of GamepadPlatform using the W3C Gamepad API.
- Inheritance
-
- Object
- PlatformInterface
- GamepadPlatform
- WebGamepad
Properties
-
events
→ Stream<
GamepadEvent> -
Stream of all gamepad events from the native platform.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Releases native resources.
override
-
listGamepads(
) → Future< List< GamepadInfo> > -
Returns a list of currently connected gamepads.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< void> -
Pauses native gamepad polling, releasing device handles.
No-op on platforms that don't hold exclusive device access.
inherited
-
resume(
) → Future< void> -
Resumes native gamepad polling after a pause.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void